"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.fetchTokensByOwnerAndMint = exports.fetchTokensByOwner = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
const generated_1 = require("./generated");
const fetchTokensByOwner = async (context, owner, options = {}) => {
    const splToken = context.programs.get('splToken').publicKey;
    const filter = options.mint
        ? { mint: (0, umi_core_1.base58PublicKey)(options.mint) }
        : { programId: (0, umi_core_1.base58PublicKey)(splToken) };
    const result = await context.rpc.call('getTokenAccountsByOwner', [(0, umi_core_1.base58PublicKey)(owner), filter], {
        ...options,
        extra: { ...options.extra, encoding: 'base64' },
    });
    return result.value.map(({ pubkey, account }) => (0, generated_1.deserializeToken)(context, {
        ...account,
        data: umi_core_1.base64.serialize(account.data[0]),
        publicKey: (0, umi_core_1.publicKey)(pubkey),
        owner: (0, umi_core_1.publicKey)(account.owner),
        lamports: (0, umi_core_1.lamports)(account.lamports),
    }));
};
exports.fetchTokensByOwner = fetchTokensByOwner;
const fetchTokensByOwnerAndMint = (context, owner, mint, options = {}) => (0, exports.fetchTokensByOwner)(context, owner, { ...options, mint });
exports.fetchTokensByOwnerAndMint = fetchTokensByOwnerAndMint;
//# sourceMappingURL=fetchTokensByOwner.js.map