"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMultisigSize = exports.getMultisigAccountDataSerializer = exports.deserializeMultisig = exports.getMultisigGpaBuilder = exports.safeFetchAllMultisig = exports.fetchAllMultisig = exports.safeFetchMultisig = exports.fetchMultisig = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
async function fetchMultisig(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_core_1.assertAccountExists)(maybeAccount, 'Multisig');
    return deserializeMultisig(context, maybeAccount);
}
exports.fetchMultisig = fetchMultisig;
async function safeFetchMultisig(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists
        ? deserializeMultisig(context, maybeAccount)
        : null;
}
exports.safeFetchMultisig = safeFetchMultisig;
async function fetchAllMultisig(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_core_1.assertAccountExists)(maybeAccount, 'Multisig');
        return deserializeMultisig(context, maybeAccount);
    });
}
exports.fetchAllMultisig = fetchAllMultisig;
async function safeFetchAllMultisig(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeMultisig(context, maybeAccount));
}
exports.safeFetchAllMultisig = safeFetchAllMultisig;
function getMultisigGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.get('splToken').publicKey;
    return (0, umi_core_1.gpaBuilder)(context, programId)
        .registerFields([
        ['m', s.u8],
        ['n', s.u8],
        ['isInitialized', s.bool()],
        ['signers', s.array(s.publicKey, 11)],
    ])
        .deserializeUsing((account) => deserializeMultisig(context, account))
        .whereSize(355);
}
exports.getMultisigGpaBuilder = getMultisigGpaBuilder;
function deserializeMultisig(context, rawAccount) {
    return (0, umi_core_1.deserializeAccount)(rawAccount, getMultisigAccountDataSerializer(context));
}
exports.deserializeMultisig = deserializeMultisig;
function getMultisigAccountDataSerializer(context) {
    const s = context.serializer;
    return s.struct([
        ['m', s.u8],
        ['n', s.u8],
        ['isInitialized', s.bool()],
        ['signers', s.array(s.publicKey, 11)],
    ], 'Multisig');
}
exports.getMultisigAccountDataSerializer = getMultisigAccountDataSerializer;
function getMultisigSize(_context = {}) {
    return 355;
}
exports.getMultisigSize = getMultisigSize;
//# sourceMappingURL=multisig.js.map