"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getTokenSize = exports.getTokenAccountDataSerializer = exports.deserializeToken = exports.getTokenGpaBuilder = exports.safeFetchAllToken = exports.fetchAllToken = exports.safeFetchToken = exports.fetchToken = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
const types_1 = require("../types");
async function fetchToken(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    (0, umi_core_1.assertAccountExists)(maybeAccount, 'Token');
    return deserializeToken(context, maybeAccount);
}
exports.fetchToken = fetchToken;
async function safeFetchToken(context, publicKey, options) {
    const maybeAccount = await context.rpc.getAccount(publicKey, options);
    return maybeAccount.exists ? deserializeToken(context, maybeAccount) : null;
}
exports.safeFetchToken = safeFetchToken;
async function fetchAllToken(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts.map((maybeAccount) => {
        (0, umi_core_1.assertAccountExists)(maybeAccount, 'Token');
        return deserializeToken(context, maybeAccount);
    });
}
exports.fetchAllToken = fetchAllToken;
async function safeFetchAllToken(context, publicKeys, options) {
    const maybeAccounts = await context.rpc.getAccounts(publicKeys, options);
    return maybeAccounts
        .filter((maybeAccount) => maybeAccount.exists)
        .map((maybeAccount) => deserializeToken(context, maybeAccount));
}
exports.safeFetchAllToken = safeFetchAllToken;
function getTokenGpaBuilder(context) {
    const s = context.serializer;
    const programId = context.programs.get('splToken').publicKey;
    return (0, umi_core_1.gpaBuilder)(context, programId)
        .registerFields([
        ['mint', s.publicKey],
        ['owner', s.publicKey],
        ['amount', s.u64],
        ['delegate', s.fixedOption(s.publicKey, s.u32)],
        ['state', (0, types_1.getTokenStateSerializer)(context)],
        ['isNative', s.fixedOption(s.u64, s.u32)],
        ['delegatedAmount', s.u64],
        ['closeAuthority', s.fixedOption(s.publicKey, s.u32)],
    ])
        .deserializeUsing((account) => deserializeToken(context, account))
        .whereSize(165);
}
exports.getTokenGpaBuilder = getTokenGpaBuilder;
function deserializeToken(context, rawAccount) {
    return (0, umi_core_1.deserializeAccount)(rawAccount, getTokenAccountDataSerializer(context));
}
exports.deserializeToken = deserializeToken;
function getTokenAccountDataSerializer(context) {
    const s = context.serializer;
    return s.struct([
        ['mint', s.publicKey],
        ['owner', s.publicKey],
        ['amount', s.u64],
        ['delegate', s.fixedOption(s.publicKey, s.u32)],
        ['state', (0, types_1.getTokenStateSerializer)(context)],
        ['isNative', s.fixedOption(s.u64, s.u32)],
        ['delegatedAmount', s.u64],
        ['closeAuthority', s.fixedOption(s.publicKey, s.u32)],
    ], 'Token');
}
exports.getTokenAccountDataSerializer = getTokenAccountDataSerializer;
function getTokenSize(_context = {}) {
    return 165;
}
exports.getTokenSize = getTokenSize;
//# sourceMappingURL=token.js.map