"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.burnTokenChecked = exports.getBurnTokenCheckedInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getBurnTokenCheckedInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.u8],
        ['amount', s.u64],
        ['decimals', s.u8],
    ], 'BurnTokenCheckedInstructionArgs'), (value) => ({ ...value, discriminator: 15 }));
}
exports.getBurnTokenCheckedInstructionDataSerializer = getBurnTokenCheckedInstructionDataSerializer;
function burnTokenChecked(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splToken').publicKey;
    const accountAccount = input.account;
    const mintAccount = input.mint;
    const authorityAccount = input.authority ?? context.identity;
    keys.push({
        pubkey: accountAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(accountAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    const data = getBurnTokenCheckedInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.burnTokenChecked = burnTokenChecked;
//# sourceMappingURL=burnTokenChecked.js.map