"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.recoverNestedAssociatedToken = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function recoverNestedAssociatedToken(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splAssociatedToken').publicKey;
    const nestedAssociatedAccountAddressAccount = input.nestedAssociatedAccountAddress;
    const nestedTokenMintAddressAccount = input.nestedTokenMintAddress;
    const destinationAssociatedAccountAddressAccount = input.destinationAssociatedAccountAddress;
    const ownerAssociatedAccountAddressAccount = input.ownerAssociatedAccountAddress;
    const ownerTokenMintAddressAccount = input.ownerTokenMintAddress;
    const walletAddressAccount = input.walletAddress;
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.get('splToken').publicKey,
        isWritable: false,
    };
    keys.push({
        pubkey: nestedAssociatedAccountAddressAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(nestedAssociatedAccountAddressAccount, true),
    });
    keys.push({
        pubkey: nestedTokenMintAddressAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(nestedTokenMintAddressAccount, false),
    });
    keys.push({
        pubkey: destinationAssociatedAccountAddressAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(destinationAssociatedAccountAddressAccount, true),
    });
    keys.push({
        pubkey: ownerAssociatedAccountAddressAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ownerAssociatedAccountAddressAccount, false),
    });
    keys.push({
        pubkey: ownerTokenMintAddressAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(ownerTokenMintAddressAccount, false),
    });
    signers.push(walletAddressAccount);
    keys.push({
        pubkey: walletAddressAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(walletAddressAccount, true),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = new Uint8Array();
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.recoverNestedAssociatedToken = recoverNestedAssociatedToken;
//# sourceMappingURL=recoverNestedAssociatedToken.js.map