"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transferTokensChecked = exports.getTransferTokensCheckedInstructionDataSerializer = void 0;
const umi_core_1 = require("@metaplex-foundation/umi-core");
function getTransferTokensCheckedInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_core_1.mapSerializer)(s.struct([
        ['discriminator', s.u8],
        ['amount', s.u64],
        ['decimals', s.u8],
    ], 'TransferTokensCheckedInstructionArgs'), (value) => ({ ...value, discriminator: 12 }));
}
exports.getTransferTokensCheckedInstructionDataSerializer = getTransferTokensCheckedInstructionDataSerializer;
function transferTokensChecked(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.get('splToken').publicKey;
    const sourceAccount = input.source;
    const mintAccount = input.mint;
    const destinationAccount = input.destination;
    const authorityAccount = input.authority ?? context.identity;
    keys.push({
        pubkey: sourceAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(sourceAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: destinationAccount,
        isSigner: false,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(destinationAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_core_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    const data = getTransferTokensCheckedInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.transferTokensChecked = transferTokensChecked;
//# sourceMappingURL=transferTokensChecked.js.map